@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2004 Zope Corporation and Contributors.
+# Copyright (c) 2004 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -13,7 +13,7 @@
 ##############################################################################
 """Browser widgets for items
 
-$Id: itemswidgets.py 107383 2009-12-30 20:21:02Z faassen $
+$Id: itemswidgets.py 112015 2010-05-05 18:27:23Z tseaver $
 """
 __docformat__ = 'restructuredtext'
 from xml.sax.saxutils import escape
@@ -154,7 +154,7 @@ class SingleDataHelper(object):
         if input:
             try:
                 return self.convertTokensToValues([input])[0]
-            except InvalidValue, e:
+            except (InvalidValue, TypeError), e:
                 raise ConversionError(_("Invalid value"), e)
         else:
             return self.context.missing_value
@@ -232,7 +232,7 @@ class ItemDisplayWidget(SingleDataHelper, ItemsWidgetBase):
     def __call__(self):
         """See IBrowserWidget."""
         value = self._getFormValue()
-        if not value:
+        if value is None or value == u'':
             return self.translate(self._messageNoValue)
         else:
             term = self.vocabulary.getTerm(value)
@@ -426,7 +426,7 @@ class SelectWidget(ItemsEditWidgetBase):
     """Provide a selection list for the item."""
 
     _messageNoValue = _("vocabulary-missing-single-value-for-edit",
-                        "(no value)")
+                        "(nothing selected)")
 
     def renderValue(self, value):
         rendered_items = self.renderItems(value)
@@ -457,7 +457,7 @@ class RadioWidget(SelectWidget):
     orientation = "vertical"
 
     _messageNoValue = _("vocabulary-missing-single-value-for-edit",
-                        "(no value)")
+                        "(nothing selected)")
 
     def renderItem(self, index, text, value, name, cssClass):
         """Render an item of the list."""
@@ -496,7 +496,7 @@ class ItemsMultiEditWidgetBase(MultiDataHelper, ItemsEditWidgetBase):
     """Items widget supporting multiple selections."""
 
     _messageNoValue = _("vocabulary-missing-multiple-value-for-edit",
-                        "(no values)")
+                        "(nothing selected)")
     _displayItemForMissingValue = False
 
     def renderItems(self, value):
@@ -626,7 +626,7 @@ class MultiCheckBoxWidget(ItemsMultiEditWidgetBase):
                              id=id,
                              value=value,
                              **kw)
-        contents = self._joinButtonToMessageTemplate % (elem, text)
+        contents = self._joinButtonToMessageTemplate % (elem, escape(text))
         return renderElement(u'label',
                              contents=contents,
                              **{'for': id})
